# earthkit

<img src="docs/_static/earthkit.png" width="120">

[![PyPI version fury.io](https://badge.fury.io/py/earthkit.svg)](https://pypi.python.org/pypi/earthkit/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/earthkit.svg)](https://pypi.python.org/pypi/earthkit/)

**DISCLAIMER**

> This project is in the **BETA** stage of development. Please be aware that interfaces and functionality may change as the project develops. If this software is to be used in operational systems you are **strongly advised to use a released tag in your system configuration**, and you should be willing to accept incoming changes and bug fixes that require adaptations on your part. ECMWF **does use** this software in operations and abides by the same caveats.

**earthkit** is a project led by ECMWF, providing powerful tools for speeding up weather and climate science workflows by simplifying data access, processing, analysis, visualisation and much more.

## Documentation

The documentation can be found at https://earthkit.readthedocs.io/.

## License

[Apache License 2.0](LICENSE) In applying this license, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
